@@ -56,8 +56,10 @@
 ##' @useDynLib geometry
 convhulln <- function (p, options = "Tv") {
   ## Check directory writable
-  if (file.access(getwd(), 2) == -1) {
-    stop(paste("Unable to write to current directory.\n",
+  tmpdir <- tempdir()
+  ## R should guarantee the tmpdir is writable, but check in any case
+  if (file.access(tmpdir, 2) == -1) {
+    stop(paste("Unable to write to R temporary directory", tmpdir, "\n",
                "This is a known issue in the geometry package\n",
                "See https://r-forge.r-project.org/tracker/index.php?func=detail&aid=5738&group_id=1149&atid=4552"))
   }
@@ -86,5 +88,5 @@ convhulln <- function (p, options = "Tv") {
   if (!grepl("Qt", options) & !grepl("QJ", options)) {
     options <- paste(options, "Qt")
   }
-  .Call("convhulln", p, as.character(options), PACKAGE="geometry")
+  .Call("convhulln", p, as.character(options), tmpdir, PACKAGE="geometry")
 }
