@@ -60,7 +60,7 @@
 ##' \code{\link{delaunayn}}, \code{\link{mesh.dsphere}},
 ##' \code{\link{mesh.hunif}},\cr \code{\link{mesh.diff}},
 ##' \code{\link{mesh.union}}, \code{\link{mesh.intersect}}
-##' @references \url{http://www-math.mit.edu/~persson/mesh/}
+##' @references \url{http://persson.berkeley.edu/distmesh/}
 ##' 
 ##' \cite{P.-O. Persson, G. Strang, A Simple Mesh Generator in MATLAB. SIAM
 ##' Review, Volume 46 (2), pp. 329-345, June 2004}
@@ -106,14 +106,14 @@ function (fdist, fh, h, box, pfix = array(dim = c(0, ncol(box))),
     # %2. Remove points outside the region, apply the rejection method
     p = p[fdist(p, ...) < geps, ]
     r0 = fh(p, ...)
-    p = rbind(pfix, p[runif(nrow(p)) < min(r0)^dim/r0^dim, ])
+    p = rbind(pfix, p[stats::runif(nrow(p)) < min(r0)^dim/r0^dim, ])
     N = nrow(p)
     if (N <= dim + 1)
         stop("Not enough starting points inside boundary (is h0 too large?).")
     on.exit(return(invisible(p)))
 
     cat("Press esc if the mesh seems fine but the algorithm hasn't converged.\n")
-    flush.console()
+    utils::flush.console()
     count = 0
 
     p0 = 1/.Machine$double.eps
@@ -149,7 +149,7 @@ function (fdist, fh, h, box, pfix = array(dim = c(0, ncol(box))),
             }
             else {
                 cat("Retriangulation #", 15, "\n")
-                flush.console()
+                utils::flush.console()
             }
             count = count + 1
         }
